@@ -46,7 +46,7 @@
 //!
 //! ```toml
 //! [dependencies]
-//! wow_srp = { version = "0.4" }
+//! wow_srp = { version = "0.4.1" }
 //! ```
 //!
 //! Then go to either the [`client`] module or [`server`] module for specific instructions.
@@ -65,7 +65,7 @@
 //!
 //! ```toml
 //! [dependencies]
-//! wow_srp = { version = "0.4", default-features = false, features = ["fast-math"] }
+//! wow_srp = { version = "0.4.1", default-features = false, features = ["fast-math"] }
 //! ```
 //!
 //! The `fast-math` feature leads to a 50% decrease in total time. It is highly recommended to enable
@@ -74,6 +74,11 @@
 //! To see the performance difference on your setup you can run `cargo bench` for the default version,
 //! and `cargo bench --features fast-math --no-default-features` for the `fast-math` version.
 //!
+//! # MSRV
+//!
+//! `wow_srp` has a Minimum Supported Rust Version (MSRV) of 1.48.0.
+//! The MSRV may be increased in `PATCH` versions before `wow_srp` reaches `1.0.0` (`MAJOR.MINOR.PATCH`).
+//!
 //! # Other implementations
 //!
 //! * [Ember](https://github.com/EmberEmu/Ember/tree/development/src/libs/srp6) is a C++ implementation for 1.12 with a clean, tested implementation of the protocol.
@@ -84,7 +89,7 @@
 //!
 //! [archive]: https://web.archive.org/web/20210620154707/https://wowdev.wiki/Login_Packet
 
-#![doc(html_root_url = "https://docs.rs/wow_srp/0.4.0")]
+#![doc(html_root_url = "https://docs.rs/wow_srp/0.4.1")]
 #![forbid(unsafe_code)]
 #![warn(
     clippy::perf,
@@ -121,3 +126,6 @@ pub(crate) mod primes;
 pub mod server;
 pub(crate) mod srp_internal;
 pub(crate) mod srp_internal_client;
+
+#[cfg(test)]
+pub(crate) mod hex;
