@@ -13,13 +13,13 @@ fn authenticate_with_self() {
     let password: NormalizedString = NormalizedString::new("A").unwrap();
     let verifier = SrpVerifier::from_username_and_password(username, password);
 
-    let password_verifier = hex::encode(&verifier.password_verifier());
-    let client_salt = hex::encode(&verifier.salt());
+    let password_verifier = *verifier.password_verifier();
+    let client_salt = *verifier.salt();
 
     let server = verifier.into_proof();
 
-    let server_salt = hex::encode(&server.salt());
-    let server_public_key = hex::encode(&server.server_public_key());
+    let server_salt = *server.salt();
+    let server_public_key = *server.server_public_key();
 
     let client = client.into_challenge(
         GENERATOR,
@@ -37,17 +37,17 @@ fn authenticate_with_self() {
         Err(e) => {
             panic!(
                 "'{}'\
-                \nverifier: {}\
-                \nclient_salt: {}\
-                \nserver_salt: {}\
-                \nserver_public_key: {}\
-                \nclient_public_key: {}",
+                \nverifier: {:02x?}\
+                \nclient_salt: {:02x?}\
+                \nserver_salt: {:02x?}\
+                \nserver_public_key: {:02x?}\
+                \nclient_public_key: {:02x?}",
                 e,
                 password_verifier,
                 client_salt,
                 server_salt,
                 server_public_key,
-                hex::encode(client_public_key),
+                client_public_key,
             )
         }
     };
@@ -59,17 +59,17 @@ fn authenticate_with_self() {
         Err(e) => {
             panic!(
                 "'{}'\
-                \nverifier: {}\
-                \nclient_salt: {}\
-                \nserver_salt: {}\
-                \nserver_public_key: {}\
-                \nclient_public_key: {}",
+                \nverifier: {:02x?}\
+                \nclient_salt: {:02x?}\
+                \nserver_salt: {:02x?}\
+                \nserver_public_key: {:02x?}\
+                \nclient_public_key: {:02x?}",
                 e,
                 password_verifier,
                 client_salt,
                 server_salt,
                 server_public_key,
-                hex::encode(client_public_key),
+                client_public_key,
             )
         }
     };
